@@ -174,6 +174,8 @@ _SEQDB = {
     '< CSI >83;40003;0c' : 'DA2 Response: could be GNU Screen 4.0.3',
     '< CSI >83;40100;0c' : 'DA2 Response: could be GNU Screen 4.1.0',
     '< CSI >85;95;c'     : 'DA2 Response: could be rxvt-unicode',
+    '< CSI $y'           : 'DECRPM / DECRQM response, report ANSI mode',
+    '< CSI ?$y'          : 'DECRPM / DECRQM response, report DEC private mode',
     '< CSI 1t'           : 'CSI 11 t Response: window is open',
     '< CSI 2t'           : 'CSI 11 t Response: window is iconified',
     '< CSI 3;[2]t'       : 'CSI 13 t Response: window position (x, y) is (%s, %s)',
@@ -592,6 +594,7 @@ _SEQDB = {
     '> CSI >0p'          : 'Pointer Mode 0: never hide the pointer',
     '> CSI >1p'          : 'Pointer Mode 1: hide if the mouse tracking mode is not enabled',
     '> CSI >2p'          : 'Pointer Mode 2: always hide the pointer',
+    '> CSI !p'           : 'DECSTR / soft terminal reset',
     '> CSI $p'           : 'DECRQM / request ANSI mode',
     '> CSI ?$p'          : 'DECRQM - DEC specific / request DEC private mode',
     '> CSI >n'           : 'disable special keyboard modifier settings (xterm)',
@@ -605,6 +608,14 @@ _SEQDB = {
     '> CSI 63;0"p'       : 'DECSCL / set conformance level: VT300 8bit control',
     '> CSI 63;1"p'       : 'DECSCL / set conformance level: VT300 7bit control',
     '> CSI 63;2"p'       : 'DECSCL / set conformance level: VT300 8bit control',
+    '> CSI [0]q'         : 'DECLL 0 / load LEDs: clear all LEDs',
+    '> CSI 0q'           : 'DECLL 0 / load LEDs: clear all LEDs',
+    '> CSI 1q'           : 'DECLL 1 / load LEDs: light num lock',
+    '> CSI 2q'           : 'DECLL 2 / load LEDs: light caps lock',
+    '> CSI 3q'           : 'DECLL 3 / load LEDs: light scroll lock',
+    '> CSI 21q'          : 'DECLL 21 / load LEDs: extinguish num lock',
+    '> CSI 22q'          : 'DECLL 22 / load LEDs: extinguish caps lock',
+    '> CSI 23q'          : 'DECLL 23 / load LEDs: extinguish scroll lock',
     '> CSI <SP>q'        : 'DECSCUSR / set cursor style',
     '> CSI [0]<SP>q'     : 'DECSCUSR 1 / set cursor style: blinking block (default)',
     '> CSI 0<SP>q'       : 'DECSCUSR 0 / set cursor style: blinking block',
@@ -619,7 +630,10 @@ _SEQDB = {
     '> CSI 0"q'          : 'DECSCA 0 / select character protection attribute: DECSED and DECSEL can erase',
     '> CSI 1"q'          : 'DECSCA 1 / select character protection attribute: DECSED and DECSEL cannot erase',
     '> CSI 2"q'          : 'DECSCA 2 / select character protection attribute: DECSED and DECSEL can erase',
-    '> CSI r'            : 'DECSTBM / set top and bottom margins',
+    '> CSI r'            : 'DECSTBM / set top and bottom margins: full size of window',
+    '> CSI [2]r'         : 'DECSTBM / set top and bottom margins: top=%s bottom=%s',
+    '> CSI [0]s'         : 'DECSLRM / set right and left margins, or Save cursor (ANSI.SYS)',
+    '> CSI [2]s'         : 'DECSLRM / set right and left margins: left=%s right=%s',
     '> CSI ?s'           : 'save DEC private mode values',
     '> CSI ?r'           : 'restore DEC private mode values',
     '> CSI [0]s'         : 'Save cursor (ANSI.SYS)',
@@ -674,6 +688,22 @@ _SEQDB = {
     '> CSI \'z'          : 'DECELR / enable locator reporting ',
     '> CSI $z'           : 'DECERA / erase rectangular area',
     '> CSI [4]$z'        : 'DECErA / erase rectangular area - top=%s, left=%s, bottom=%s, right=%s',
+    '> CSI `$'           : 'DECSLE / select locator events',
+    '> CSI [0]`$'        : 'DECSLE 0 / select locator events: only respond to explicit host requests',
+    '> CSI 0`$'          : 'DECSLE 0 / select locator events: only respond to explicit host requests',
+    '> CSI 1`$'          : 'DECSLE 1 / select locator events: report button down transitions',
+    '> CSI 2`$'          : 'DECSLE 2 / select locator events: do not report button down transitions',
+    '> CSI 3`$'          : 'DECSLE 3 / select locator events: report button up transitions',
+    '> CSI 4`$'          : 'DECSLE 4 / select locator events: do not report button up transitions',
+    '> CSI ${'           : 'DECSERA / selective erase rectangular area',
+    '> CSI [4]${'        : 'DECSERA / selective erase rectangular area (%s, %s, %s, %s)',
+    '> CSI `|'           : 'DECRQLP / request locator position',
+    '> CSI `}'           : 'DECIC / insert Ps Column(s)',
+    '> CSI [0]`}'        : 'DECIC 1 / insert a Column(s)',
+    '> CSI [1]`}'        : 'DECIC / insert %s Column(s)',
+    '> CSI `~'           : 'DECDC / insert Ps Column(s)',
+    '> CSI [0]`~'        : 'DECDC / insert a Column(s)',
+    '> CSI [1]`~'        : 'DECDC / insert %s Column(s)',
 }
 
 _DEFAULT_CONF = """
